==> gstreamer-0.5.1.tar.bz2: gstreamer-0.5.1/gst/elements/gstmultidisksrc.h <==
/* GStreamer
 * Copyright (C) 1999,2000 Erik Walthinsen <omega@cse.ogi.edu>
 *                    2000 Wim Taymans <wtay@chello.be>
 *                    2001 Dominic Ludlam <dom@recoil.org>
 *
 * gstmultidisksrc.h: 
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GST_MULTIDISKSRC_H__
#define __GST_MULTIDISKSRC_H__

#include <gst/gst.h>

G_BEGIN_DECLS

GstElementDetails gst_multidisksrc_details;

#define GST_TYPE_MULTIDISKSRC \
  (gst_multidisksrc_get_type())
#define GST_MULTIDISKSRC(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_MULTIDISKSRC,GstMultiDiskSrc))
#define GST_MULTIDISKSRC_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_MULTIDISKSRC,GstMultiDiskSrcClass))
#define GST_IS_MULTIDISKSRC(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_MULTIDISKSRC))
#define GST_IS_MULTIDISKSRC_CLASS(obj) \
  (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_MULTIDISKSRC))

typedef enum {
  GST_MULTIDISKSRC_OPEN		= GST_ELEMENT_FLAG_LAST,

  GST_MULTIDISKSRC_FLAG_LAST	= GST_ELEMENT_FLAG_LAST + 2,
} GstMultiDiskSrcFlags;

typedef struct _GstMultiDiskSrc GstMultiDiskSrc;
typedef struct _GstMultiDiskSrcClass GstMultiDiskSrcClass;

struct _GstMultiDiskSrc {
  GstElement element;
  /* pads */
  GstPad *srcpad;

  /* current file details */
  gchar  *currentfilename;
  GSList *listptr;

  /* mapping parameters */
  gint fd;
  gulong size;    /* how long is the file? */
  guchar *map;    /* where the file is mapped to */

  gboolean new_seek;
};

struct _GstMultiDiskSrcClass {
  GstElementClass parent_class;

  void (*new_file)  (GstMultiDiskSrc *multidisksrc, gchar *newfilename);
};

GType gst_multidisksrc_get_type(void);

G_END_DECLS

#endif /* __GST_MULTIDISKSRC_H__ */

==> gstreamer-0.6.5.tar.bz2: gstreamer-0.6.5/gst/elements/gstmultidisksrc.h <==
/* GStreamer
 * Copyright (C) 1999,2000 Erik Walthinsen <omega@cse.ogi.edu>
 *                    2000 Wim Taymans <wtay@chello.be>
 *                    2001 Dominic Ludlam <dom@recoil.org>
 *
 * gstmultidisksrc.h: 
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GST_MULTIDISKSRC_H__
#define __GST_MULTIDISKSRC_H__

#include <gst/gst.h>

G_BEGIN_DECLS

extern GstElementDetails gst_multidisksrc_details;

#define GST_TYPE_MULTIDISKSRC \
  (gst_multidisksrc_get_type())
#define GST_MULTIDISKSRC(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_MULTIDISKSRC,GstMultiDiskSrc))
#define GST_MULTIDISKSRC_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_MULTIDISKSRC,GstMultiDiskSrcClass))
#define GST_IS_MULTIDISKSRC(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_MULTIDISKSRC))
#define GST_IS_MULTIDISKSRC_CLASS(obj) \
  (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_MULTIDISKSRC))

typedef enum {
  GST_MULTIDISKSRC_OPEN		= GST_ELEMENT_FLAG_LAST,

  GST_MULTIDISKSRC_FLAG_LAST	= GST_ELEMENT_FLAG_LAST + 2
} GstMultiDiskSrcFlags;

typedef struct _GstMultiDiskSrc GstMultiDiskSrc;
typedef struct _GstMultiDiskSrcClass GstMultiDiskSrcClass;

struct _GstMultiDiskSrc {
  GstElement element;
  /* pads */
  GstPad *srcpad;

  /* current file details */
  gchar  *currentfilename;
  GSList *listptr;

  /* mapping parameters */
  gint fd;
  gulong size;    /* how long is the file? */
  guchar *map;    /* where the file is mapped to */

  gboolean new_seek;
};

struct _GstMultiDiskSrcClass {
  GstElementClass parent_class;

  void (*new_file)  (GstMultiDiskSrc *multidisksrc, gchar *newfilename);
};

GType gst_multidisksrc_get_type(void);

G_END_DECLS

#endif /* __GST_MULTIDISKSRC_H__ */
